import { Pico } from "./Pico";
import { PicoEvent } from "./PicoEvent";
import { PicoQuery } from "./PicoQuery";
import { LevelBatch } from "./utils";
export interface ChannelConfig {
    tags?: string[];
    eventPolicy?: EventPolicy;
    queryPolicy?: QueryPolicy;
}
export interface ChannelReadOnly {
    id: string;
    tags: string[];
    eventPolicy: EventPolicy;
    queryPolicy: QueryPolicy;
    familyChannelPicoID: string | null;
}
export declare class Channel {
    id: string;
    pico: Pico;
    /**
     * A way to categorize channels i.e. bulk update of a group of channels
     */
    tags: string[];
    /**
     * pico-engine had shared policies, however there were more problems by sharing that space
     * pico-framework policies are denormalized i.e. each channel owns their own copy
     */
    eventPolicy: EventPolicy;
    queryPolicy: QueryPolicy;
    /**
     * This is set by the family member (parent-child relation) who owns this channel.
     * Only this pico is allowed to send messages through it.
     */
    familyChannelPicoID?: string;
    constructor(pico: Pico, id: string, conf?: ChannelConfig, familyChannelPicoID?: string);
    update(conf: ChannelConfig): void;
    assertEventPolicy(event: PicoEvent, fromPicoID?: string): void;
    assertQueryPolicy(query: PicoQuery, fromPicoID?: string): void;
    private assertIfFamilyChannel;
    toReadOnly(): ChannelReadOnly;
    toDbPut(): LevelBatch;
    toDbDel(): LevelBatch;
    static fromDb(pico: Pico, val: any): Channel;
}
export declare function assertEventPolicy(eventPolicy: EventPolicy, event: PicoEvent): void;
export declare function assertQueryPolicy(queryPolicy: QueryPolicy, query: PicoQuery): void;
export interface EventPolicy {
    allow: EventPolicyRule[];
    deny: EventPolicyRule[];
}
export interface EventPolicyRule {
    domain: string;
    name: string;
}
export interface QueryPolicy {
    allow: QueryPolicyRule[];
    deny: QueryPolicyRule[];
}
export interface QueryPolicyRule {
    rid: string;
    name: string;
}
export declare function cleanEventPolicy(orig: any): EventPolicy;
export declare function cleanQueryPolicy(orig: any): QueryPolicy;
export declare function cleanChannelTags(tags: any): string[];
