"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PicoQueue = void 0;
class PicoQueue {
    constructor(picoId, worker, emit) {
        this.picoId = picoId;
        this.worker = worker;
        this.emit = emit;
        // TODO use flumelog-offset or similar
        this.txnLog = [];
        this.txnWaiters = {};
        this.isWorking = false;
    }
    push(txn) {
        Object.freeze(txn);
        this.txnLog.push(txn);
        this.emit({
            type: "txnQueued",
            picoId: this.picoId,
            txn
        });
        setTimeout(() => this.doWork(), 0);
    }
    waitFor(id) {
        return new Promise((resolve, reject) => {
            this.txnWaiters[id] = { resolve, reject };
        });
    }
    getCurrentTxn() {
        return this.currentTxn;
    }
    async doWork() {
        if (this.isWorking) {
            return;
        }
        this.isWorking = true;
        while ((this.currentTxn = this.txnLog.shift())) {
            let txn = this.currentTxn;
            let data;
            let error;
            this.emit({
                type: "txnStart",
                picoId: this.picoId,
                txn
            });
            try {
                data = await this.worker(txn);
            }
            catch (err) {
                error = err;
            }
            if (error) {
                this.emit({
                    type: "txnError",
                    picoId: this.picoId,
                    txn,
                    error
                });
            }
            else {
                this.emit({
                    type: "txnDone",
                    picoId: this.picoId,
                    txn,
                    data
                });
            }
            if (this.txnWaiters[txn.id]) {
                if (error) {
                    this.txnWaiters[txn.id].reject(error);
                }
                else {
                    this.txnWaiters[txn.id].resolve(data);
                }
                delete this.txnWaiters[txn.id];
            }
        }
        this.txnWaiters = {};
        this.isWorking = false;
        this.currentTxn = undefined;
    }
}
exports.PicoQueue = PicoQueue;
//# sourceMappingURL=PicoQueue.js.map