"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createRulesetContext = void 0;
/**
 * This is a constructor function to be sure that we don't leak things that a ruleset should not have access to.
 *
 * @param pf the framework
 * @param pico the pico the ruleset is installed on
 * @param ruleset info/config about the installed ruleset
 */
function createRulesetContext(pf, pico, ruleset) {
    const rid = ruleset.rid;
    return {
        ruleset,
        event(event) {
            return pf.event(event, pico.id);
        },
        eventQuery(event, query) {
            return pf.eventQuery(event, query, pico.id);
        },
        query(query) {
            return pf.query(query, pico.id);
        },
        pico() {
            return pico.toReadOnly();
        },
        newPico(conf) {
            return pico.newPico(conf);
        },
        delPico(eci) {
            return pico.delPico(eci);
        },
        async newChannel(conf) {
            const chann = await pico.newChannel(conf);
            return chann.toReadOnly();
        },
        async putChannel(eci, conf) {
            const chann = await pico.putChannel(eci, conf);
            return chann.toReadOnly();
        },
        delChannel(eci) {
            return pico.delChannel(eci);
        },
        install(rs, config) {
            return pico.install(rs, config);
        },
        uninstall(rid) {
            return pico.uninstall(rid);
        },
        getEnt(name) {
            return pico.getEnt(rid, name);
        },
        putEnt(name, value) {
            return pico.putEnt(rid, name, value);
        },
        delEnt(name) {
            return pico.delEnt(rid, name);
        },
        raiseEvent(domain, name, attrs, forRid) {
            return pico.raiseEvent(domain, name, attrs, forRid);
        },
        clearSchedule() {
            pico.clearSchedule();
        }
    };
}
exports.createRulesetContext = createRulesetContext;
//# sourceMappingURL=RulesetContext.js.map